@@ -2,6 +2,8 @@
  *
  * Copyright 2014 Red Hat, Inc.
  *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -182,7 +184,7 @@ test_threaded_712570 (void)
   GSocketClient *client;
   GError *error = NULL;
 
-  g_test_bug ("712570");
+  g_test_bug ("https://bugzilla.gnome.org/show_bug.cgi?id=712570");
 
   g_mutex_lock (&mutex_712570);
 
@@ -557,8 +559,6 @@ main (int   argc,
 {
   g_test_init (&argc, &argv, NULL);
 
-  g_test_bug_base ("http://bugzilla.gnome.org/");
-
   g_test_add_func ("/socket-service/start-stop", test_start_stop);
   g_test_add_func ("/socket-service/threaded/712570", test_threaded_712570);
   g_test_add_func ("/socket-service/read_write_async", test_read_write_async);
