@@ -1,6 +1,8 @@
 /* GLIB - Library of useful routines for C programming
  * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
  *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
@@ -73,22 +75,29 @@
  */
 
 static void
-g_string_maybe_expand (GString *string,
-                       gsize    len)
+g_string_expand (GString *string,
+                 gsize    len)
 {
   /* Detect potential overflow */
   if G_UNLIKELY ((G_MAXSIZE - string->len - 1) < len)
     g_error ("adding %" G_GSIZE_FORMAT " to string would overflow", len);
 
-  if (string->len + len >= string->allocated_len)
-    {
-      string->allocated_len = g_nearest_pow (string->len + len + 1);
-      /* If the new size is bigger than G_MAXSIZE / 2, only allocate enough
-       * memory for this string and don't over-allocate. */
-      if (string->allocated_len == 0)
-        string->allocated_len = string->len + len + 1;
-      string->str = g_realloc (string->str, string->allocated_len);
-    }
+  string->allocated_len = g_nearest_pow (string->len + len + 1);
+  /* If the new size is bigger than G_MAXSIZE / 2, only allocate enough
+   * memory for this string and don't over-allocate.
+   */
+  if (string->allocated_len == 0)
+    string->allocated_len = string->len + len + 1;
+
+  string->str = g_realloc (string->str, string->allocated_len);
+}
+
+static inline void
+g_string_maybe_expand (GString *string,
+                       gsize    len)
+{
+  if (G_UNLIKELY (string->len + len >= string->allocated_len))
+    g_string_expand (string, len);
 }
 
 /**
@@ -111,7 +120,7 @@ g_string_sized_new (gsize dfl_size)
   string->len   = 0;
   string->str   = NULL;
 
-  g_string_maybe_expand (string, MAX (dfl_size, 64));
+  g_string_expand (string, MAX (dfl_size, 64));
   string->str[0] = 0;
 
   return string;
@@ -146,6 +155,41 @@ g_string_new (const gchar *init)
   return string;
 }
 
+/**
+ * g_string_new_take: (constructor)
+ * @init: (nullable) (transfer full): initial text used as the string.
+ *     Ownership of the string is transferred to the #GString.
+ *     Passing %NULL creates an empty string.
+ *
+ * Creates a new #GString, initialized with the given string.
+ *
+ * After this call, @init belongs to the #GString and may no longer be
+ * modified by the caller. The memory of @data has to be dynamically
+ * allocated and will eventually be freed with g_free().
+ *
+ * Returns: (transfer full): the new #GString
+ *
+ * Since: 2.78
+ */
+GString *
+g_string_new_take (gchar *init)
+{
+  GString *string;
+
+  if (init == NULL)
+    {
+      return g_string_new (NULL);
+    }
+
+  string = g_slice_new (GString);
+
+  string->str = init;
+  string->len = strlen (string->str);
+  string->allocated_len = string->len + 1;
+
+  return string;
+}
+
 /**
  * g_string_new_len: (constructor)
  * @init: initial contents of the string
@@ -190,12 +234,15 @@ g_string_new_len (const gchar *init,
  * it's %FALSE, the caller gains ownership of the buffer and must
  * free it after use with g_free().
  *
+ * Instead of passing %FALSE to this function, consider using
+ * g_string_free_and_steal().
+ *
  * Returns: (nullable): the character data of @string
  *          (i.e. %NULL if @free_segment is %TRUE)
  */
 gchar *
-g_string_free (GString  *string,
-               gboolean  free_segment)
+(g_string_free) (GString  *string,
+                 gboolean  free_segment)
 {
   gchar *segment;
 
@@ -214,6 +261,25 @@ g_string_free (GString  *string,
   return segment;
 }
 
+/**
+ * g_string_free_and_steal:
+ * @string: (transfer full): a #GString
+ *
+ * Frees the memory allocated for the #GString.
+ *
+ * The caller gains ownership of the buffer and
+ * must free it after use with g_free().
+ *
+ * Returns: (transfer full): the character data of @string
+ *
+ * Since: 2.76
+ */
+gchar *
+g_string_free_and_steal (GString *string)
+{
+  return (g_string_free) (string, FALSE);
+}
+
 /**
  * g_string_free_to_bytes:
  * @string: (transfer full): a #GString
@@ -349,8 +415,8 @@ g_string_assign (GString     *string,
  * Returns: (transfer none): @string
  */
 GString *
-g_string_truncate (GString *string,
-                   gsize    len)
+(g_string_truncate) (GString *string,
+                     gsize    len)
 {
   g_return_val_if_fail (string != NULL, NULL);
 
@@ -530,8 +596,8 @@ g_string_append_uri_escaped (GString     *string,
  * Returns: (transfer none): @string
  */
 GString *
-g_string_append (GString     *string,
-                 const gchar *val)
+(g_string_append) (GString     *string,
+                   const gchar *val)
 {
   return g_string_insert_len (string, -1, val, -1);
 }
@@ -555,9 +621,9 @@ g_string_append (GString     *string,
  * Returns: (transfer none): @string
  */
 GString *
-g_string_append_len (GString     *string,
-                     const gchar *val,
-                     gssize       len)
+(g_string_append_len) (GString     *string,
+                       const gchar *val,
+                       gssize       len)
 {
   return g_string_insert_len (string, -1, val, len);
 }
@@ -572,10 +638,9 @@ g_string_append_len (GString     *string,
  *
  * Returns: (transfer none): @string
  */
-#undef g_string_append_c
 GString *
-g_string_append_c (GString *string,
-                   gchar    c)
+(g_string_append_c) (GString *string,
+                     gchar    c)
 {
   g_return_val_if_fail (string != NULL, NULL);
 
